                processor 6502
                include "vcs.h"
                include "macro.h"

;--------------------------
;--  CONSTANTS
;--------------------------
                
ARENA_HEIGHT = 72

    ;--- Arena Sprite Boundaries
ARENA_LEFT   = 20
ARENA_RIGHT  = 133
ARENA_TOP    = 72
ARENA_BOTTOM = 15

VBLANK_TIME   = 45  ;--- VSYNC + VBLANK Time for TIM64T
OVERSCAN_TIME = 38  ;--- OVERSCAN Time for TIM64T
DISPLAY_TIME  = 14  ;--- DISPLAY Time for T1024T

;--------------------------
;--  VARIABLES
;--------------------------

                SEG.U vars
                ORG $80
                
    ; DoDraw Graphic Pointers
Player0Ptr:         ds 2    ; used for drawing player0
Player1Ptr:         ds 2    ; used for drawing player1
Player0Draw:        ds 1    ; used for drawing player0
Player1Draw:        ds 1    ; used for drawing player1

    ; Other graphics drawing pointers / data
TitleColors:        ds 4
Color0:             ds 2
Color0Ptr:          ds 2
Color1:             ds 2
Color1Ptr:          ds 2

    ; Sprite positions
ObjectX         ds 2             ; x coordinate
ObjectY			ds 2
GameRunning		ds 1
LivesDisplay:	ds 5

Rand:			ds 1
Rand16:          ds 1  

LiveColor		    ds 1
PlayfieldColor	    ds 1
Temp			    ds 1
ScoreDisplayRight   ds 5
ScoreDisplayLeft    ds 5

Frame:          ds 1    
Score:          ds 2    
ScoreTimer:		ds 1
DigitOnes:      ds 2    ; stored in $82-83, DigitOnes = Score, DigitOnes+1 = Score+1
DigitTens:      ds 2    ; stored in $84-85, DigitTens = Score, DigitTens+1 = Score+1
  
EndNoise:		ds 1
ScoreCounter:   ds 1
RevoltMoving:  ds 2
BeebotDir:	ds 2
Lives:			ds 1
BeginningBotPlace: ds 1
EnemyBeesMoveTimer: ds 1
EnemyBeesMoveTimerSecs: ds 1
EnemyBeesDir: ds 1
EnemyBeesType: ds 1
BeesTouchTimer: ds 1
RayUse: ds 1
RayTimer: ds 1
ThereIsACollision: ds 1

;-----------------------------
; variables used by the bees

beesOfs         ds 1        ;--- offset into bee graphics (for sprite version)

    ;--- other bees use BALL object
otherBeesX      ds 1
otherBeesY      ds 1        ;--- Y position of other bees
otherBeesYCnt   ds 1        ;--- Y counter for other bees
otherBeesOfs    ds 1        ;--- graphics offset for other bees

BeebotSpeed		ds 1
BeebotMoveTimer ds 1
BeebotMoveSeconds ds 1

SFXTimer		ds 1   

; beebot - player 0
; your bees  - player 1
; rosha ray - missile 1
; enemy bees - ball
; missile 0 is free.

;------------------
; END OF VARIABLES
;------------------


              
                SEG code
                ORG $F000
	
;---------------------------------------------------------
;------ Random number generator
    
Random:
        lda Rand
        lsr
 ifconst Rand16
        rol Rand16
 endif
        bcc noeor
        eor #$B4 
noeor 
        sta Rand
 ifconst Rand16
        eor Rand16
 endif
        rts 	
        
;--------------------------------------------------------
;------ Position Object
;
;--   reg A = X position
;--   reg X = Object#  (0=P0, 1=P1, 2=M0, 3=M1, 4=BL)
        
PosObject:
        sec
        sta WSYNC
DivideLoop
        sbc #15        ; 2  2 - each time thru this loop takes 5 cycles, which is 
        bcs DivideLoop ; 2  4 - the same amount of time it takes to draw 15 pixels
        eor #7         ; 2  6 - The EOR & ASL statements convert the remainder
        asl            ; 2  8 - of position/15 to the value needed to fine tune
        asl            ; 2 10 - the X position
        asl            ; 2 12
        asl            ; 2 14
        sta.wx HMP0,X  ; 5 19 - store fine tuning of X
        sta RESP0,X    ; 4 23 - set coarse X position of Player
		rts

;---------------------------------------------------
;--  Game boots to here
        
Reset
   ; Clear RAM and all TIA registers
        CLEAN_START      
		
        ;--- Initialize some variables
Reset2:
        lda #$1a
        sta LiveColor

        lda #$9c
        sta PlayfieldColor

        lda #1
        sta GameRunning	

        lda #$00
        sta BeebotMoveSeconds
		sta AUDV1
		sta EnemyBeesType


        lda #88
        sta TitleColors+0

        lda #98
        sta TitleColors+1
        sta Rand		
        sta Rand16

        lda #$C8
        sta TitleColors+2

        lda #30
        sta TitleColors+3
				
		lda #5
		sta Lives
				
TitleScreenLoop:
	 	lda GameRunning
		cmp #2
		bne TitleScreen
        jmp Main
        
TitleScreen:
        lda #$0e
        sta COLUBK

        jsr VerticalSync
        jsr VerticalBlank	
        jsr Kernel
        jsr StartOverscan
        
        jsr Bees_buzzing_at_title_screen

        lda INPT4               ;--- check if player started the game
        bmi TitleScreenLoop

StartGame:
        lda #$00
        sta Score
        sta Score+1
 	
        sta AUDV0
        
        jsr VerticalSync
        jsr VerticalBlank	
        jsr Kernel
        jsr StartOverscan		
        
        lda INPT4               ;--- check if player started the game
        bpl StartGame	
		
        lda #2
        sta GameRunning
		
        lda #72
        sta ObjectX+1

        lda #49
        sta ObjectY+1
        sta COLUP1
        
		lda #2
		sta HMOVE
		lda #%11110000
		sta HMM1
		sta HMM1
		lda #%11000000
		sta HMM1

		lda #0
	    sta COLUBK	
		
		lda #4
		sta RayUse
		
		jsr Begin_new_Enemy_Bees
	
Begin_a_new_Beebot:	
				lda #1
				sta BeebotMoveTimer
				sta BeebotSpeed
				sta BeebotMoveSeconds
				
				jsr Random
				and #3
				sta BeginningBotPlace

				lda BeginningBotPlace
				cmp #0
				beq Beebot_0

				cmp #1
				beq Beebot_1
				
				cmp #2
				beq Beebot_2
				
Beebot_3:
				; lower left
				lda #10
				sta ObjectX+0			
				
				lda #22
				sta ObjectY+0					
			
				jmp Main
				
Beebot_2:
				; lower right
				lda #140
				sta ObjectX+0			
				
				lda #22
				sta ObjectY+0					
			
				jmp Main
				
Beebot_1:
				; upper left
				lda #10
				sta ObjectX+0			
				
				lda #54
				sta ObjectY+0					
			
				jmp Main
				
Beebot_0:
				; upper right
				lda #140
				sta ObjectX+0			
				
				lda #54
				sta ObjectY+0
				
				jmp Main

Begin_new_Enemy_Bees:	
                lda #0
				sta EnemyBeesMoveTimer
				sta EnemyBeesMoveTimerSecs
				sta EnemyBeesType
				
				jsr Random
				and #3
				sta BeginningBotPlace

				lda BeginningBotPlace
				cmp #0
				beq Bees_0

				cmp #1
				beq Bees_1
				
				cmp #2
				beq Bees_2
				
Bees_3:
				; lower left
				lda #10
				sta otherBeesX			
				
				lda #27
				sta otherBeesY
			
				lda #1
				sta EnemyBeesDir			
			
				rts
				
Bees_2:
				; lower right
				lda #140
				sta otherBeesX			
				
				lda #27
				sta otherBeesY					
			
				lda #2
				sta EnemyBeesDir		
			
				rts
				
Bees_1:
				; upper left
				lda #10
				sta otherBeesX			
				
				lda #62
				sta otherBeesY

				lda #1
				sta EnemyBeesDir					
			
				rts
				
Bees_0:
				; upper right
				lda #140
				sta otherBeesX		
				
				lda #62
				sta otherBeesY
				
				lda #2
				sta EnemyBeesDir				
				
				rts

Main:
			jsr VerticalSync
			jsr VerticalBlank	
			
            jsr PositionObjects
            jsr ProcessJoystick
			

			jsr Move_Enemy_Bees
            jsr UseRoshaRay	
	

		
			jsr Kernel
			jsr StartOverscan
			jsr Move_Beebot
			jsr Check_Enemy_Bee_Collisions	
		
			lda Lives
			cmp #0
			beq Reset____ 
	
			lda SWCHB                        ; read the console switches
			lsr                              ; shift game reset to carry
			bcc Reset____                   ; skip game reset	
	
			jmp Main

Reset____:
				
			jsr VerticalSync
			jsr VerticalBlank	
			jsr Kernel
			jsr StartOverscan		

			jmp Reset2

Bees_buzzing_at_title_screen:
				lda #06
				sta AUDC0
				sta AUDV0
		
				jsr Random
				and #$0f
				adc #$09
				sta AUDF0
		
				;jsr AddScoreTest
		
				rts
				
Go_other_bees_____
				jmp Go_other_bees
				
Enemy_bees_dead:

				
				lda #12
				sta AUDC0
				sta AUDF0
				sta SFXTimer
				
				lda #5
				sta AUDV0
				
				jsr AddFiveToScore
				jsr Begin_new_Enemy_Bees
				
				rts
				
Move_Enemy_Bees:
				inc EnemyBeesMoveTimer

				lda EnemyBeesMoveTimer
				cmp #3
				beq Actually_Move_Enemy_Bees	

				rts
				
Red_Devil_Bees_X______	
					jmp Red_Devil_Bees_X
				
Actually_Move_Enemy_Bees:
				lda #0
				sta EnemyBeesMoveTimer
				
				lda EnemyBeesType
				cmp #32
				bcs Red_Devil_Bees_X______					
						
				cmp #16
				bcs Guardian_Bees_X			
				
 
				
Random_Enemy_Bees:				
				inc EnemyBeesMoveTimerSecs

				lda EnemyBeesMoveTimerSecs
				cmp #20
				beq Get_New_Enemy_Bee_Dir
				
Move_those_bees_now:
				lda EnemyBeesDir
				cmp #1
				beq OtherBeesRight
	
				cmp #2
				beq OtherBeesLeft
				
				cmp #3
				beq OtherBeesUp

OtherBeesDown:
				lda otherBeesY
				cmp #66
				beq OtherBeesUp				

				lda #4
				sta EnemyBeesDir

				inc otherBeesY
				rts
				
OtherBeesUp:
				lda otherBeesY
				cmp #20
				beq OtherBeesDown			


				lda #3
				sta EnemyBeesDir

				dec otherBeesY
				rts	
				
OtherBeesLeft:
				lda otherBeesX
				cmp #20
				beq OtherBeesRight				

				lda #2
				sta EnemyBeesDir

				dec otherBeesX
				rts
				
OtherBeesRight:
				lda otherBeesX
				cmp #130
				beq OtherBeesLeft	

				lda #1
				sta EnemyBeesDir

				inc otherBeesX
				rts	

Get_New_Enemy_Bee_Dir:
				inc EnemyBeesType

				lda #0
				sta EnemyBeesMoveTimerSecs

				jsr Random
				and #3
				adc #1
				sta EnemyBeesDir
				
				rts
				
Guardian_Bees_X:
				inc EnemyBeesMoveTimerSecs

				lda EnemyBeesMoveTimerSecs
				cmp #20
				beq Get_New_Guardian_Bee_Timer

				jmp Dont_Get_New_Guardian_Bee_Timer
				
Get_New_Guardian_Bee_Timer		
				lda #0
				sta EnemyBeesMoveTimerSecs
	
				inc EnemyBeesType

Dont_Get_New_Guardian_Bee_Timer
		        lda otherBeesX
				sbc #4
				cmp ObjectX+0
				bcs OtherBeesLeft2

OtherBeesRight2:
				inc otherBeesX
				jmp Guardian_Bees_Y
				
OtherBeesLeft2:
				dec otherBeesX
				
Guardian_Bees_Y:	
		        lda otherBeesY
				cmp ObjectY+0
				bcs OtherBeesUp2

OtherBeesDown2:
				inc otherBeesY
				rts
				
OtherBeesUp2:
				dec otherBeesY
				rts
	
	
Red_Devil_Bees_X:
				lda #65
				sta EnemyBeesType

		        lda otherBeesX
				sbc #4
				cmp ObjectX+1
				bcs OtherBeesLeft3

				inc otherBeesX
				jmp Red_Devil_Y

OtherBeesLeft3:
				dec otherBeesX
				
Red_Devil_Y:	
		        lda otherBeesY
				cmp ObjectY+1
				bcs OtherBeesUp3

OtherBeesDown3:
				inc otherBeesY
				rts
				
OtherBeesUp3:
				dec otherBeesY
				rts
	
PrepScoreForDisplay:      
        ldx #4
PSFDloop:
        lda Lives   ;Lives digit
        and #$0F
        sta Temp
        asl
        asl
        adc Temp
        sta Temp
        txa
        adc Temp
        tay
        lda DigitFlippedGfx,y
        and #$F0
        sta LivesDisplay,x
        
        lda Score   ; thousandths digit
        and #$F0
        lsr
        lsr
        sta Temp
        lsr
        lsr
        adc Temp    
        sta Temp
        txa
        adc Temp
        tay
        lda DigitFlippedGfx,y
        and #$0F
        sta ScoreDisplayLeft,x
        
        lda Score   ;hundredths digit
        and #$0F
        sta Temp
        asl
        asl
        adc Temp
        sta Temp
        txa
        adc Temp
        tay
        lda DigitFlippedGfx,y
        and #$F0
        ora ScoreDisplayLeft,x
        sta ScoreDisplayLeft,x
        
        lda Score+1   ; tenths digit
        and #$F0
        lsr
        lsr
        sta Temp
        lsr
        lsr
        adc Temp    
        sta Temp
        txa
        adc Temp        
        tay
        lda DigitGfx,y
        and #$F0
        sta ScoreDisplayRight,x
        
        lda Score+1   ;ones digit
        and #$0F
        sta Temp
        asl
        asl
        adc Temp
        sta Temp
        txa
        adc Temp        
        tay
        lda DigitGfx,y
        and #$0F
        ora ScoreDisplayRight,x
        sta ScoreDisplayRight,x        
        
        dex
        bpl PSFDloop
        rts     	

;----------------------------------------
;----- Handle Vertical Sync
        
VerticalSync:

OSwait:
        sta WSYNC
        lda INTIM
        bpl OSwait  ; wait for the timer to denote end of Overscan	

        lda #$2             ; DGS - LoaD Accumulator with $82 so D7=1 and D1=1
        ldx #VBLANK_TIME    ; 
        
        sta WSYNC       ; Wait for SYNC (halts CPU until end of scanline)
        sta VSYNC       ; Accumulator D1=1, turns on Vertical Sync signal
        sta VBLANK      ; DGS - turn off video, dump paddles to ground
        stx TIM64T      ; set timer to go off in 41 scanlines (49 * 64) / 76
        sta CTRLPF      ; D1=1, playfield now in SCORE mode
        
;        lda Frame  ;---------- Hmmmm, what is this suppose to do?
;        and #$3f
;        bne VSskip  
VSskip: inc Frame       ; increment Frame count

        sta WSYNC   ; Wait for Sync - halts CPU until end of 1st scanline of VSYNC
        lda #0       ;$30    ; 
        sta NUSIZ0  ; set missile0 to be 1x   NOT 8x
		
		lda #%00110000
        sta NUSIZ1  ; set missile1 to be 8x   
        
        sta WSYNC   ; wait until end of 2nd scanline of VSYNC
        lda #0      ; LoaD Accumulator with 0 so D1=0
        sta PF0     ; blank the playfield
        sta PF1     ; blank the playfield
        sta PF2     ; blank the playfield
        sta GRP0    ; blanks player0 if VDELP0 was off
        sta GRP1    ; blanks player0 if VDELP0 was on, player1 if VDELP1 was off 
        sta GRP0    ; blanks                           player1 if VDELP1 was on		
        sta VDELP0  ; turn off Vertical Delay
        sta VDELP1  ; turn off Vertical Delay
        sta CXCLR   ; clear collision detection latches
        sta WSYNC   ; wait until end of 3rd scanline of VSYNC
        sta VSYNC   ; Accumulator D1=0, turns off Vertical Sync signal
Sleep12:            ;       jsr here to sleep for 12 cycles        
        rts         ; ReTurn from Subroutine
		
        
        
VerticalBlank:
        jsr Random
		jsr PrepScoreForDisplay
	
AddScoreTest:
		ldx EndNoise
		inx		
		stx EndNoise
	
	 	ldx EndNoise
		cpx #15
		beq TS_Color_change
		
		rts
		
        
ProcessJoystick:
        lda SWCHA       ; fetch state of both joysticks
        
        asl                     ; shift A bits left, R is now in the carry bit
        bcs CheckLeft            ; branch if joystick not held down
        ldy ObjectX+1            ; get the object's Y position
        cpy #ARENA_RIGHT      ; test for right of screen
        beq SaveX               ; save Y if we're not at the right		
        iny                     ; move it down



SaveX:  sty ObjectX+1            ; save Y

CheckLeft:
        asl                     ; shift A bits left, L is now in the carry bit
        bcs CheckDown    ; branch if joystick not held up
        ldy ObjectX+1            ; get the object's Y position

        cpy #ARENA_LEFT     ; test for top of screen
        beq SaveX2              ; save Y if we're not at the top
		


		
	    dey                     ; move it up	
   
SaveX2: sty ObjectX+1            ; save Y

CheckDown:
        asl                     ; shift A bits left, D is now in the carry bit
        bcs CheckUp             ; branch if joystick not held down
        ldy ObjectY+1            ; get the object's Y position
        cpy #ARENA_BOTTOM       ; test for bottom of screen
        beq SaveY               ; save Y if we're not at the bottom		
        dey                     ; move it down

SaveY:  sty ObjectY+1            ; save Y

CheckUp:
        asl                     ; shift A bits left, U is now in the carry bit
        bcs DoneWithJoystick    ; branch if joystick not held up
        ldy ObjectY+1            ; get the object's Y position

        cpy #ARENA_TOP          ; test for top of screen
        beq SaveY2              ; save Y if we're not at the top
		
	    iny                     ; move it up	
   
SaveY2: sty ObjectY+1            ; save Y

DoneWithJoystick:



        rts		
  
AddFiveToScore:
        sed             ; turn on decimal mode
        clc
        lda Score+1     ; Score+1 holds the Tens and Ones digits
        adc #5          ; add 5 to score
        sta Score+1
        lda Score       ; Score holds the Thousands and Hundreds digits
        adc #0          ; add 0 to this digit, carry will inc by 1 if needed
        sta Score       ;
        cld             ; turn off decimal mode


		rts
      
		
AddOneToScore:
        sed             ; turn on decimal mode
        clc
        lda Score+1     ; Score+1 holds the Tens and Ones digits
        adc #1          ; add 1 to score
        sta Score+1
        lda Score       ; Score holds the Thousands and Hundreds digits
        adc #0          ; add 0 to this digit, carry will inc by 1 if needed
        sta Score       ;
        cld             ; turn off decimal mode


		rts

TS_Color_change:
		ldx #0
		stx EndNoise

		lda TitleColors+1
		sta TitleColors+0	

		lda TitleColors+2
		sta TitleColors+1	

		lda TitleColors+3
		sta TitleColors+2	
	
		lda TitleColors+4
		sta TitleColors+3	
	
		jsr Random
		sta TitleColors+4		
		rts

PositionObjects:
        ldx #1              ; position players 0 and 1
POloop:
        lda #(ARENA_HEIGHT + Beebot_HEIGHT)
        sec
        sbc ObjectY
        sta Player0Draw

        lda ObjectX,x       ; get the Player's X position
        jsr PosObject      ; set coarse X position and fine-tune amount 
			
        dex                 ; DEcrement X
        bpl POloop          ; Branch PLus so we position all Players

		lda ObjectX+1
		ldx #3          ;-- missile 1
		jsr PosObject	        
		
		lda RayUse		
		cmp #2
		bne Go_other_bees
		
		inc RayTimer
		
		lda RayTimer
		cmp #30
		beq QuitRay
		

	
		jmp Go_other_bees
			

				
QuitRay:
		lda #0
		sta RayTimer
		
		lda #4
		sta RayUse
		
Go_other_bees:	
        ;----------------- position other bees horizontally
        lda otherBeesX
        ldx #4          ;-- other bees use ball
        jsr PosObject
        
        sta WSYNC           ; wait for end of scanline
        sta HMOVE           ; Tell TIA to use fine-tune values to set final X positions
  

  
 	 	lda EndNoise
		cmp #7
		bcc Frame2
  
  
  
     ; Player0Draw = ARENA_HEIGHT + HUMAN_HEIGHT - Y_position
        lda #<(BeebotGFX + Beebot_HEIGHT - 1)
        sec
        sbc ObjectY+0
        sta Player0Ptr
        lda #>(BeebotGFX + Beebot_HEIGHT - 1)
        sbc #0
        sta Player0Ptr+1 
  
		jmp POLoop0
  
  
Frame2:
    ; Player0Draw = ARENA_HEIGHT + HUMAN_HEIGHT - Y_position
        lda #<(BeebotGFX2 + Beebot_HEIGHT - 1)
        sec
        sbc ObjectY+0
        sta Player0Ptr
        lda #>(BeebotGFX2 + Beebot_HEIGHT - 1)
        sbc #0
        sta Player0Ptr+1
		
		
		
		
POLoop0:	
    ;  setup other bees
	lda   Frame
	lsr
    and  #3
    adc  #0
	sta  otherBeesOfs
	lda   #11
	sbc  otherBeesOfs
	sta  otherBeesOfs



		lda ThereIsACollision
		cmp #1
		beq Change_Beebot_to_Blue


        lda #<(BeebotColors + Beebot_HEIGHT - 1)   ; DGS33
        sec                                 ; DGS33
        sbc ObjectY+0                       ; DGS33
        sta Color0Ptr                       ; DGS33
        lda #>(BeebotColors + Beebot_HEIGHT - 1)   ; DGS33
        sbc #0                              ; DGS33
        sta Color0Ptr+1                     ; DGS33		

		jmp DDDDDDD

Change_Beebot_to_Blue
        lda #<(BeebotColors2 + Beebot_HEIGHT - 1)   ; DGS33
        sec                                 ; DGS33
        sbc ObjectY+0                       ; DGS33
        sta Color0Ptr                       ; DGS33
        lda #>(BeebotColors2 + Beebot_HEIGHT - 1)   ; DGS33
        sbc #0                              ; DGS33
        sta Color0Ptr+1                     ; DGS33		

DDDDDDD:
		
        ;-- setup player bee graphics offset to random #
        lda Rand
        and #7
        sta <beesOfs

    ; Player1Draw = ARENA_HEIGHT + BOX_HEIGHT - Y_position
        lda #(ARENA_HEIGHT + Bees_HEIGHT)
        sec
        sbc ObjectY+1
        sta Player1Draw        
       
    
    ;--- Offset bee graphics
        lda ObjectY+1
        sec
        sbc beesOfs
        sta beesOfs
    
    ; Set Player1Ptr to proper value for drawing player1
        lda #<(BeesGFX + Bees_HEIGHT - 1)
        sec
        sbc beesOfs
        ;adc <beesOfs            ;--  PB: offset bee graphics
        sta Player1Ptr
        lda #>(BeesGFX + Bees_HEIGHT - 1)
        sbc #0
        sta Player1Ptr+1	

		lda #$0e
		sta COLUP1

		rts
        
;------------------------------------------------------------------------------
;-----  Beebot Move Handler
	
MoveBeebotLeft____
		jmp MoveBeebotLeft
	
MoveBeebotRight___
	jmp MoveBeebotRight
	
Move_Beebot:
		lda #0
		sta ThereIsACollision	

            lda ObjectX+0
            cmp #134
            bcs MoveBeebotLeft____
			
            lda ObjectX+0
            cmp #19
            bcc MoveBeebotRight___
			
		lda BeebotMoveTimer
        cmp BeebotSpeed
        beq Actually_Move_Beebot

		inc BeebotMoveTimer

		lda CXPPMM                 ; 3         or player/player and 
		and #%10000000             ; 2         mask ball, M0/M0, M0/P0 collisions
        bne ArghWork	
		
		
		
		
		jmp Finish_Moving_Beebot

Actually_Move_Beebot:
   		lda #1
		sta BeebotMoveTimer
			
		lda RevoltMoving+0
        cmp #2
        bcs MoveBeebotOppositeX2

		lda CXPPMM                 ; 3         or player/player and 
		and #%10000000             ; 2         mask ball, M0/M0, M0/P0 collisions
        bne MoveBeebotOppositeX2	




            lda RevoltMoving+0
            cmp #1
            bcs MoveBeebotOppositeX	

			lda #0
			sta RevoltMoving+0

            lda ObjectX+0
            cmp ObjectX+1
            bcc MoveBeebotLeft
			
			jmp MoveBeebotRight
			
MoveBeebotOppositeX2:
		lda CXPPMM                 ; 3         or player/player and 
		and #%10000000             ; 2         mask ball, M0/M0, M0/P0 collisions
        bne ArghWork
	

		lda #0
		sta ThereIsACollision	
	
		jmp Finish_Moving_Beebot_4

ArghWork:
		lda #1
		sta ThereIsACollision	

		inc BeebotMoveSeconds
		
		lda BeebotMoveSeconds
        cmp #32
        beq IHATETHIS
		
        cmp #33
        bcs IHATEHTIS
	
		jmp Finish_Moving_Beebot_3
		
IHATETHIS
		inc BeebotSpeed	

		lda #0
		sta BeebotMoveSeconds	

IHATEHTIS


			lda #2
			sta AUDC0
			sta AUDF0
			

		
			inc SFXTimer
		
			lda SFXTimer
			cmp #7
			bcs Finish_Moving_Beebot_4			
	
			lda #6
			sta AUDV0	
	
	
			jmp Finish_Moving_Beebot_3
	
Finish_Moving_Beebot_4:
			lda #0
			sta AUDV0
			sta SFXTimer
			sta BeebotMoveSeconds
	
Finish_Moving_Beebot_3:
			lda #2
			sta RevoltMoving+0	
	
            lda BeebotDir+0
            cmp #1
            beq MoveBeebotLeft	
		
			jmp MoveBeebotRight
			
MoveBeebotOppositeX:
			lda #1
			sta RevoltMoving+0

            lda BeebotDir+0
            cmp #2
            beq MoveBeebotLeft			
			
MoveBeebotRight:
			lda #2
			sta BeebotDir+0

            lda ObjectX+0
            cmp #ARENA_RIGHT
            bcs Beebot_RightBorder	

			inc ObjectX+0

			lda #0
			sta REFP0
	
			jmp Move_Beebot_y			
				
Beebot_RightBorder:
			lda #0
			sta RevoltMoving+0

			lda #1
			sta BeebotDir+0	

			jmp Move_Beebot_y
			
MoveBeebotLeft:
			lda #1
			sta BeebotDir+0

            lda ObjectX+0
            cmp #ARENA_LEFT
            bcc Beebot_LeftBorder

			dec ObjectX+0
			
			lda #8
			sta REFP0			
			
			jmp Move_Beebot_y
			
Beebot_LeftBorder:
			lda #0
			sta RevoltMoving+0

			lda #2
			sta BeebotDir+0
			
			jmp Move_Beebot_y			
			
Move_Beebot_y:	
        lda RevoltMoving+1
        cmp #2
        bcs MoveBeebotOppositeY2

		lda CXPPMM                 ; 3         or player/player and 
		and #%10000000             ; 2         mask ball, M0/M0, M0/P0 collisions
        bne MoveBeebotOppositeY2	

            lda RevoltMoving+1
            cmp #1
            bcs MoveBeebotOppositeY	

			lda #0
			sta RevoltMoving+1

            lda ObjectY+0
            cmp ObjectY+1
            bcc MoveBeebotUp
			
			jmp MoveBeebotDown
			
MoveBeebotOppositeY2:
			lda #2
			sta RevoltMoving+1	
	
            lda BeebotDir+1
            cmp #1
            beq MoveBeebotUp	
			
			jmp MoveBeebotDown
			
MoveBeebotOppositeY:
			lda #1
			sta RevoltMoving+1

            lda BeebotDir+1
            cmp #2
            beq MoveBeebotUp
			
MoveBeebotDown:
			lda #2
			sta BeebotDir+1

            lda ObjectY+0
            cmp #ARENA_TOP
            bcs Beebot_DownBorder	

			inc ObjectY+0
			
			jmp Finish_Moving_Beebot			
				
Beebot_DownBorder:
			lda #0
			sta RevoltMoving+1

			lda #1
			sta BeebotDir+1		
			
			jmp Finish_Moving_Beebot
			
MoveBeebotUp:
			lda #1
			sta BeebotDir+1

            lda ObjectY+0
            cmp #ARENA_BOTTOM+1
            bcc Beebot_UpBorder

			dec ObjectY+0
			
			jmp Finish_Moving_Beebot
			
Beebot_UpBorder:
			lda #0
			sta RevoltMoving+1

			lda #2
			sta BeebotDir+1		
			

Finish_Moving_Beebot:
			
		lda BeebotSpeed
        cmp #5
        bcs Score_A_Point			
			
			rts
			
Enemy_bees_dead______:
			jmp Enemy_bees_dead			
			
Check_Enemy_Bee_Collisions			
		lda CXP1FB	             ; 3      
		and #%01000000           ; 2     
        bne Bees_Collision				
			
		lda #0	
		sta BeesTouchTimer		
			
		lda CXM1FB 
		and #%01000000             ; 2         mask ball, M0/M0, M0/P0 collisions
		bne Enemy_bees_dead______					
				
		rts

Bees_Collision:
		lda BeesTouchTimer
        cmp #2
        beq Lose_A_Life

		inc BeesTouchTimer

		rts
		
Lose_A_Life
		lda #12
		sta SFXTimer
		sta AUDC0
		
		lda #6		
		sta AUDV0
		
		lda #1
		sta AUDF0

		lda #0
		sta BeesTouchTimer

		dec Lives
		
		rts

DontUseRay
		lda #1
		sta RayUse	
		
		rts

Cant_use_ray
			lda SFXTimer
			cmp #12
			bcc Cant_use_ray_no_more

			inc SFXTimer
		
			lda SFXTimer
			cmp #31
			beq Silence
			
			lda #4
			sta RayUse
			

Cant_use_ray_no_more
		rts		
		
Silence:
		lda #0
		sta AUDV0
		sta SFXTimer
		rts
		
		
UseRoshaRay
		lda RayUse
        cmp #4
        beq Cant_use_ray
		
		lda RayTimer
        cmp #1
        bcs RayInUse		
		
        lda INPT4               ;--- check if player started the game
        bmi DontUseRay

		lda #2
		sta RayUse
		sta RayTimer
		
RayInUse:
		rts

Score_A_Point
		sleep 20
	
		lda #200
		sta ObjectY+0
	
		lda BeebotSpeed
        cmp #6
        bcs SkipPointAdd

		jsr AddOneToScore
		
		lda #1
		sta RayUse		
		
		
	
SkipPointAdd:
		inc BeebotSpeed
	
		lda BeebotSpeed
		cmp #15
        beq jumpTo_New_Beebot_2
		
		lda #6
		sta AUDC0
		sta AUDV0
		sta AUDF0	
	
		rts		
			
jumpTo_New_Beebot_2:    jmp New_Beebot_2
        
;------------------------------------------------------------------------------
;---- Main Display Kernel
        
Kernel:      
		jsr Random

        lda INTIM       ; 4  4 - check the timer
        bne Kernel    ; 2  6 - (3 7) Branch if its Not Equal to 0
        
        sta WSYNC       ; Wait for SYNC (halts CPU until end of scanline)  
        
    ; turn on the display
        sta VBLANK      ; 3  9 - Accumulator D1=0, turns off Vertical Blank signal (image output on)        
		lda #$01          ; 2 11
		sta CTRLPF      ; 3 14 - turn on playfield mirroring

        
    ;-- Start the timer for the Display Kernel
        lda #DISPLAY_TIME
        sta T1024T
		
		ldx #0
        ldy #ARENA_HEIGHT       ;init loop counter
		stx ENAM1

		lda RayUse
		cmp #1
		beq GreenScore
	
		lda #$36
		sta PlayfieldColor
		
		jmp ScoreLoop2

GreenScore
		lda #$D6
		sta PlayfieldColor

		
		
ScoreLoop2:
        sta WSYNC
;---------------------------------------
        lda LivesDisplay,x      ; 4  4
        sta PF0                 ; 3  7 - update PF0 for left side of screen
        lda LiveColor                ; 2  9
        sta COLUPF              ; 3 12
        lda ScoreDisplayLeft,x  ; 4 16
        sta PF2                 ; 3 19 - update PF2 for left side of screen
        jsr Sleep12             ;12 31
        lda PlayfieldColor              ; 2 33
        sta COLUPF              ; 3 36
        SLEEP 3                 ; 5 41
        lda ScoreDisplayRight,x ; 4 45
        sta PF2                 ; 3 48 - @48 - update PF2 for right side of screen
        lda #0                  ; 2 50
        sta PF0                 ; 3 53 - update PF0 for right side of screen
        sta WSYNC
;---------------------------------------
        lda LivesDisplay,x      ; 4  4
        sta PF0                 ; 3  7 - update PF0 for left side of screen
        lda LiveColor               ; 2  9
        sta COLUPF              ; 3 12        
        lda ScoreDisplayLeft,x  ; 4 11
        sta PF2                 ; 3 14 - update PF2 for left side of screen
        jsr Sleep12             ;12 26
        lda PlayfieldColor                ; 2 33
        sta COLUPF              ; 3 36
        SLEEP 3                 ; 5 41
        lda ScoreDisplayRight,x ; 4 45
        sta PF2                 ; 3 48 - @48 - update PF2 for right side of screen
        lda #0                  ; 2 50
        sta PF0                 ; 3 53 - update PF0 for right side of screen
        inx                     ; 2 55
        cpx #5                  ; 
        bne ScoreLoop2	   ; 3 58

Rest_of_score_stuff:
;---------------------------------------
        lda #0          ; 2  2
		sta PF1
		sta PF2	
		tax            ; used by Draw_MrCelery loop
        sta WSYNC       ; 3  6 - wait for end of scanline
;---------------------------------------  
		lda #$00
		sta COLUPF	
				
	 	ldx GameRunning
		cpx #1
		bne KeepGoing
        
        jmp WriteTitle
        
KeepGoing:
        ;lda #$00	; don't forget to close this!
        ;sta AUDV0

        lda #$00
        sta COLUBK	  

	 	lda EnemyBeesType
		cmp #32
		bcs RedBees

		cmp #16
		bcs BlueBees

		lda #$CA
		sta COLUPF

		lda #$02
		sta AUDV1	
          
		jmp GameBoardDrawing

BlueBees:
		lda #$9A
		sta COLUPF
          
		lda #$04
		sta AUDV1		  
		  
		  
		jmp GameBoardDrawing

RedBees:
		lda #$3A
		sta COLUPF
		
		lda #$06
		sta AUDV1
          
		jmp GameBoardDrawing

      
  
GameBoardDrawing:    
				lda #06
				sta AUDC1
		
				jsr Random
				and #$0f
				adc #$09
				sta AUDF1
   
    ;--------------------------------------------------
    ;---- Now draw the gameboard
    
        sta  WSYNC
        lda #0
        sta PF0
        sta PF1	
        sta PF2      

        sta  WSYNC

        ldy  #19
DrawTopBeeBox:
        sta  WSYNC		 
        lda  #0
        sta  PF2        
        dey
        bpl  DrawTopBeeBox
        
        ldy  #4
DrawArenaTopBorder:
        sta WSYNC               ; wait till end of scanline
        lda #%11111111	
        sta PF1	
        sta PF2      

        dey
        bpl DrawArenaTopBorder
                        
    ;-------------------------------------------------------
    ;---- at this point, DRAW the main arena section
    
        ldy #ARENA_HEIGHT   ;-- used as counter for Arena (playfield and sprites)
            
MainArena:
        ldx #0
        sta WSYNC
        stx HMCLR
        stx PF0
        lda #%10000000
        sta PF1
        lda #%00000000		
        sta PF2      
		

		
GameBoardLoop:              ;--- enters at 29
DrawTheScreen:				

        ;------------------------------------------------
        ;--  handle other bees as missile  (21 cycles)
        
        ldx  otherBeesYCnt          ;3  32
        bne  DrawOtherBees          ;2  34    -- branch if we are still drawing other bees
        
        sta  ENABL                  ;3  37    -- clear other bees
        
        cpy  otherBeesY             ;3  40 --- is it time to draw other bees?
        bne  Draw_sprites_routine   ;2  42  --- skip if not
        
        ;-- setup to draw other bees
        lda  <otherBeesOfs          ;3  45 --- a randomish offset is used
        sbc  #2                     ;2  47
        sta  otherBeesYCnt          ;3  50
        jmp  Draw_sprites_routine   ;3  53

DrawOtherBees:      ;-- enters at 35

        lda  beesAsMissile,x    ;4  39  -- load bees missile pattern
        sta   ENABL             ;3  42
        sta   HMBL              ;3  45
        
        dec otherBeesYCnt       ;5  50


Draw_sprites_routine:
        lda #0 
        sta WSYNC
        sta HMOVE
        lda #0          ;-- clear side boxes to "hide" the HMOVE bar
        sta PF0


		lda RayUse
		sta ENAM1
		
		
		
		


ArenaLoop:                  ; - 11 - time of longest path here
        lda #Beebot_HEIGHT-1 ; 2 13 - height of the human graphics, 
        dcp Player0Draw     ; 5 18 - Decrement Player0Draw and compare with height
        bcs DoDrawGrp0      ; 2 20 - (3 21) if Carry is Set then player0 is on current scanline
        lda #0              ; 2 22 - otherwise use 0 to turn off player0
        .byte $2C           ; 4 26 - $2C = BIT with absolute addressing, trick that
                            ;        causes the lda (Player0Ptr),y to be skipped
DoDrawGrp0:                 ;   21 - from bcs DoDrawGRP0
        lda (Player0Ptr),y  ; 5 26 - load the shape for player0
        tax                 ; 2 28 - save in X for update during Horizontal Blanking
        lda (Color0Ptr),y   ; DGS33   
        sta Color0          ; DGS33  
        
        lda #Beebot_HEIGHT-1   ; 2 30 - height of the box graphics, subtract 1 due to starting with 0
        dcp Player1Draw     ; 5 35 - Decrement Player1Draw and compare with height
        bcs DoDrawGrp1      ; 2 37 - (3 38) if Carry is Set, then player1 is on current scanline
        lda #0              ; 2 39 - otherwise use 0 to turn off player1
        .byte $2C           ; 4 43 - $2C = BIT with absolute addressing, trick that
                            ;        causes the lda (Player1Ptr),y to be skipped
DoDrawGrp1:                 ;   38 - from bcs DoDrawGrp1
        lda (Player1Ptr),y  ; 5 43 - load the shape for player1
        sta WSYNC           ; 3 46/0 - halts CPU until start of next scanline
		
        stx GRP0            ; 3  3 - draw the human
		sta GRP1            ; 3  6 - draw the box
        
       lda Color0          ; 3  9   DGS33
       sta COLUP0          ; 3  12   DGS33
	
    ;----- draw sides of arena
        
        lda  ArenaGfxPF0-6,y    ;4  16
        sta  PF0                ;3  19

        dey                     ;2  21 - update loop counter
                
        cpy  #6                 ;3  24
        beq  DoneArena          ;2  26
        jmp  GameBoardLoop      ;3  29

    ;--------------------------------------
    ;----- done drawing arena
DoneArena:
		ldy #0
		sty ENAM1

        ldy  #4
				
GameBoard13:    
        sta WSYNC               ; wait till end of scanline
        lda #0
        sta PF0
        lda #%11111111		
        sta PF1	
        sta PF2      
        
        dey
        bpl GameBoard13

       
GameBoard14:    
        sta WSYNC               ; wait till end of scanline
        lda #0
        sta PF0
        sta PF1	
        sta PF2   
        
        ;-- now wait until display time is done

WaitForEndOfDisplay
        lda INTIM
        bpl WaitForEndOfDisplay          
        rts
				
                
;--------------------------------------------------
;----- Title Screen display kernel  - SUBROUTINE
        
	
WriteTitle:   

        sta CTRLPF      ; 3  5 - turn off SCORE mode

        sta WSYNC               ; wait till end of scanline

        lda #$0e
        sta COLUBK	  

        lda #0
        sta PF0				
        sta PF1
        sta PF2
        inx
        cpx #40
        bne WriteTitle
        
Title1:    
        sta WSYNC               ; wait till end of scanline
        lda #%10000000
        sta PF0
        lda #%00101010		; k i l
        sta PF1
        lda #%01101101		; r e l
        sta PF2      
        sleep 21
        lda #0
        sta PF0				
        lda #%11110110		;  b e
        sta PF1
        lda #%00011011		; s e 
        sta PF2
        
        inx
        cpx #43
        bne Title1

Title2:
        sta WSYNC              ; wait till end of scanline
        lda #%10000000
        sta PF0	
        lda #%01000010		; k i l
        sta PF1
        lda #%00101101		; r e l
        sta PF2      
        sleep 21
        lda #%10010110		;   b e
        sta PF1
        lda #%00001011		; s e 
        sta PF2
        lda #0
        sta PF0           
     
        inx
        cpx #46
        bne Title2				

Title3:
        sta WSYNC
        lda #%10000000
        sta PF0				
        lda #%10001010		; k i l
        sta PF1
        lda #%00101101		; r e l
        sta PF2   
        sleep 21
        lda #%11100110		;   b e
        sta PF1

        lda #%00011011		; s e 
        sta PF2
        lda #0
        sta PF0				
        
        inx
        cpx #49
        bne Title3

Title4:
        sta WSYNC
        lda #%10000000
        sta PF0					
        
        lda #%01001010		; k i l
        sta PF1
        lda #%00100101		; r e l
        sta PF2  
        sleep 21
        lda #%10010100		;   b e
        sta PF1
        lda #%00010001		; s e 
        sta PF2
        lda #0
        sta PF0				

        inx
        cpx #52
        bne Title4

Title5:
        sta WSYNC		
                
        lda #%10000000
        sta PF0					
                
        lda #%00101010		; k i l
        sta PF1
        lda #%00101101		; r e l
        sta PF2  
        sleep 21
        lda #0
        sta PF0						
        lda #%11110110		;   b e
        sta PF1
        lda #%00011011		;  s e
        sta PF2

        inx
        cpx #55
        bne Title5

Title5a:
        sta WSYNC	
            
        lda #0		
        sta PF0					
        sta PF1		
        sta PF2	

        inx
        cpx #60
        bne Title5a

        lda TitleColors+0
        sta COLUPF

Title6:
        sta WSYNC		
                
        lda #255		
        sta PF1		
        sta PF2	
        
        lda #%10001010
        sta PF0	
        
        sleep 22

        lda #255		
        sta PF1			
        sta PF0	
        
        lda #%00011111
        sta PF2	

        inx
        cpx #70
        bne Title6


        
Title7:
        sta WSYNC		
    
        lda TitleColors+1
        sta COLUPF	
    
        lda #0		
        sta PF0
    
        lda #%00001111
        sta PF1	

        lda #255				
        sta PF2

        sleep 21

        lda #255	
        sta PF0
        sta PF1
        
        lda #0
        sta PF2

        inx
        cpx #80
        bne Title7
        
        lda TitleColors+2
        sta COLUPF		
        
Title8:
        sta WSYNC	
        
        lda #0		
        sta PF1
        sta PF0
        
        lda #255
        sta PF2	

        sleep 21

        lda #255	
        sta PF0

        lda #%11110000
        sta PF1	

        lda #0
        sta PF2				
    
        inx
        cpx #90
        bne Title8		

        lda TitleColors+3
        sta COLUPF	

Title9:
        sta WSYNC	
        
        lda #0		
        sta PF0
        sta PF1	
        
        lda #%11110000
        sta PF2

        sleep 24

        lda #255	
        sta PF0

        lda #0
        sta PF1	
        sta PF2			
    
        inx
        cpx #100
        bne Title9			

Title10:    
        sta WSYNC               ; wait till end of scanline

        lda #0
        sta PF0
        sta PF1      
        sta PF2
        
        ;-- because WriteTitle is a subroutine,
        ;---    we can jump to WaitForEndOfDisplay
        ;---    which will do the RTS for use
        
        jmp WaitForEndOfDisplay  


					
StartOverscan:
        sta WSYNC   ; Wait for SYNC (start of next scanline)
        lda #2      ; LoaD Accumulator with 2
        sta VBLANK  ; STore Accumulator to VBLANK, D1=1 turns image output off
        lda #OVERSCAN_TIME
        sta TIM64T  ; set timer for end of Overscan    	
        rts
        
        
;-----------------------------------------------------
;--- Another beebot handler?
        
        

New_Beebot_2:

        lda #0
        sta AUDV0

        lda #1
		sta BeebotMoveTimer
        sta BeebotSpeed
        sta BeebotMoveSeconds

        jsr Random
        and #3
        sta BeginningBotPlace

        lda BeginningBotPlace
        cmp #0
        beq Beebot_02

        cmp #1
        beq Beebot_12
        
        cmp #2
        beq Beebot_22
        
Beebot_32:
        ; lower left
        lda #10
        sta ObjectX+0			
        
        lda #22
        sta ObjectY+0					
    
        rts
        
Beebot_22:
        ; lower right
        lda #140
        sta ObjectX+0			
        
        lda #22
        sta ObjectY+0					
    
        rts
        
Beebot_12:
        ; upper left
        lda #10
        sta ObjectX+0			
        
        lda #54
        sta ObjectY+0					
    
        rts
        
Beebot_02:
        ; upper right
        lda #140
        sta ObjectX+0			
        
        lda #54
        sta ObjectY+0				

        rts

;-----------------------------------------------------
;----  Graphics        
		
DigitGfx:
        .byte %01110111
        .byte %01010101
        .byte %01010101
        .byte %01010101
        .byte %01110111
        
        .byte %00100010
        .byte %01100110
        .byte %00100010
        .byte %00100010       
        .byte %01110111
        
        .byte %01110111
        .byte %00010001
        .byte %01110111
        .byte %01000100
        .byte %01110111
        
        .byte %01110111
        .byte %00010001
        .byte %00110011
        .byte %00010001
        .byte %01110111
        
        .byte %01010101
        .byte %01010101
        .byte %01110111
        .byte %00010001
        .byte %00010001
        
        .byte %01110111
        .byte %01000100
        .byte %01110111
        .byte %00010001
        .byte %01110111
           
        .byte %01110111
        .byte %01000100
        .byte %01110111
        .byte %01010101
        .byte %01110111
        
        .byte %01110111
        .byte %00010001
        .byte %00010001
        .byte %00010001
        .byte %00010001
        
        .byte %01110111
        .byte %01010101
        .byte %01110111
        .byte %01010101
        .byte %01110111
        
        .byte %01110111
        .byte %01010101
        .byte %01110111
        .byte %00010001
        .byte %01110111

DigitFlippedGfx:
        .byte %11101110
        .byte %10101010
        .byte %10101010
        .byte %10101010
        .byte %11101110
        
        .byte %01000100
        .byte %01100110
        .byte %01000100
        .byte %01000100       
        .byte %11101110
        
        .byte %11101110
        .byte %10001000
        .byte %11101110
        .byte %00100010
        .byte %11101110
        
        .byte %11101110
        .byte %10001000
        .byte %11001100
        .byte %10001000
        .byte %11101110
        
        .byte %10101010
        .byte %10101010
        .byte %11101110
        .byte %10001000
        .byte %10001000
        
        .byte %11101110
        .byte %00100010
        .byte %11101110
        .byte %10001000
        .byte %11101110
           
        .byte %11101110
        .byte %00100010
        .byte %11101110
        .byte %10101010
        .byte %11101110
        
        .byte %11101110
        .byte %10001000
        .byte %10001000
        .byte %10001000
        .byte %10001000
        
        .byte %11101110
        .byte %10101010
        .byte %11101110
        .byte %10101010
        .byte %11101110
        
        .byte %11101110
        .byte %10101010
        .byte %11101110
        .byte %10001000
        .byte %11101110
			
BeebotGFX:
		.byte #%00011000
		.byte #%00010000
		.byte #%00010000				
		.byte #%00111100		
		.byte #%01000010	
		.byte #%01000010	
		.byte #%00111100	
		.byte #%01100110	
		
BeebotGFX2:
		.byte #%01001100
		.byte #%01101000
		.byte #%00101000			
		.byte #%00111100		
		.byte #%01000010	
		.byte #%01000010	
		.byte #%00111100	
		.byte #%01100110			
		
		
Beebot_HEIGHT = * - BeebotGFX2

BeesGFX:
		.byte #%00010000			
		.byte #%01000010		
		.byte #%00100000
		.byte #%00001000
		.byte #%00100000			
		.byte #%00000010	
		.byte #%00000100
		.byte #%01000000		

Bees_HEIGHT = * - BeesGFX

BeesGFX2:                   ;-- bee graphics for handling random offset
		.byte #%00100000	
		.byte #%00001000
		.byte #%00100000
		.byte #%00000000
		.byte #%00000010
		.byte #%00010100	
		.byte #%00000000
		.byte #%01000100

            
beesAsMissile:
    .byte $00,
    .byte $00,$22,$D2,$32
    .byte $00,$E2,$32,$D2
    .byte $00,$22,$D2,$32
    .byte $00,$E2,$32,$D2
    .byte $00,$00		

BeebotColors2:
		.byte #$0e
		.byte #$0e
		.byte #$0e
		.byte #$34
		.byte #$34
		.byte #$34
		.byte #$34
		.byte #$34
		
BeebotColors:
		.byte #$0e
		.byte #$0e
		.byte #$0e
		.byte #$8a
		.byte #$8a
		.byte #$8a
		.byte #$8a
		.byte #$8a

;---------------------------------------------------------
;---- Playfield graphics for Drawing Arena
        
TopBoxGfxPF2:           ;-- NOTE: graphics is upside down (due to index counting down)
    .byte %00100000,0
    .byte %00100000,0
    .byte %00100000,0
    .byte %00100000,0
    .byte %00100000,0
    .byte %00100000,0
    .byte %00100000,0
    .byte %00100000,0
    .byte %11100000,0
    .byte %11100000,0
    

ArenaGfxPF0:
    .byte %00000000,%00000000,%00000000,%00000000,%00000000  ;24-28
    .byte %00000000,%00000000,%00000000,%00000000,%00000000  ;29-33
    
    .byte %11110000,%11110000                                ;34-35 -- bottom box / bottom border
    
    .byte %00010000,%00010000,%00010000,%00010000,%00010000  ;36-40
    .byte %00010000,%00010000,%00010000,%00010000,%00010000  ;41-45
    
    .byte %11110000,%11110000                                ;46-47 -- bottom box / top border
    
    .byte %00000000,%00000000,%00000000,%00000000,%00000000  ;48-52
    .byte %00000000,%00000000,%00000000,%00000000,%00000000  ;53-57
    .byte %00000000,%00000000,%00000000,%00000000,%00000000  ;58-62
    .byte %00000000,%00000000,%00000000,%00000000,%00000000  ;63-67
    
    .byte %11110000,%11110000                                ;68-69 -- top box / bottom border
    
    .byte %00010000,%00010000,%00010000,%00010000,%00010000  ;70-74
    .byte %00010000,%00010000,%00010000,%00010000,%00010000  ;75-79
    
    .byte %11110000,%11110000                                ;80-81 -- top box / top border
    
    .byte %00000000,%00000000,%00000000,%00000000,%00000000  ;82-86
    .byte %00000000,%00000000,%00000000,%00000000,%00000000  ;87-91


;;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; ;; Function to check for free space at end of cart.
;;; ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

	echo "------", [$FFFA - *]d, "bytes free before End of Cartridge"

            ORG $FFFA

InterruptVectors
            .word Reset			        ; NMI
            .word Reset         ; RESET
            .word Reset           ; IRQ

      END